==> activity-center-api-1.0.2-20160620.021236-21-sources.jar: cn/com/duiba/activity/center/api/dto/ngame/DuibaNgameOptionsDto.java <==
package cn.com.duiba.activity.center.api.dto.ngame;

import java.io.Serializable;
import java.util.Date;

public class DuibaNgameOptionsDto implements Serializable{
	
	private static final long serialVersionUID = -9137580180385890159L;
	private Long id;
	private Long duibaGameId;
	private Long itemId;
	private String prizeName;
	private Integer payload;
	private String prizeType;
	private String facePrice;
	private Boolean hidden;
	private Boolean autoOpen;
	private String logo;
	private String description;
	private Boolean deleted;
	private Date gmtCreate;
	private Date gmtModified;
	private Integer remaining;
	
	/*奖项个数*/
	private Integer optionCount;
	/*新增奖项个数*/
	private Integer newOptionCount;
	
	private Boolean valid;
	private Boolean addrLimit;
	
	public Long getDuibaGameId() {
		return duibaGameId;
	}
	public void setDuibaGameId(Long duibaGameId) {
		this.duibaGameId = duibaGameId;
	}
	public String getPrizeName() {
		return prizeName;
	}
	public void setPrizeName(String prizeName) {
		this.prizeName = prizeName;
	}
	public Boolean getAutoOpen() {
		return autoOpen;
	}
	public void setAutoOpen(Boolean autoOpen) {
		this.autoOpen = autoOpen;
	}
	public Boolean getValid() {
		return valid;
	}
	public void setValid(Boolean valid) {
		this.valid = valid;
	}
	public Boolean getAddrLimit() {
		return addrLimit;
	}
	public void setAddrLimit(Boolean addrLimit) {
		this.addrLimit = addrLimit;
	}
	public Integer getNewOptionCount() {
		return newOptionCount;
	}
	public void setNewOptionCount(Integer newOptionCount) {
		this.newOptionCount = newOptionCount;
	}
	public Integer getOptionCount() {
		return optionCount;
	}
	public void setOptionCount(Integer optionCount) {
		this.optionCount = optionCount;
	}
	public Long getId() {
		return id;
	}
	public void setId(Long id) {
		this.id = id;
	}
	public Long getItemId() {
		return itemId;
	}
	public void setItemId(Long itemId) {
		this.itemId = itemId;
	}
	public Integer getPayload() {
		return payload;
	}
	public void setPayload(Integer payload) {
		this.payload = payload;
	}
	public String getPrizeType() {
		return prizeType;
	}
	public void setPrizeType(String prizeType) {
		this.prizeType = prizeType;
	}
	public String getFacePrice() {
		return facePrice;
	}
	public void setFacePrice(String facePrice) {
		this.facePrice = facePrice;
	}
	public Boolean getHidden() {
		return hidden;
	}
	public void setHidden(Boolean hidden) {
		this.hidden = hidden;
	}
	public String getLogo() {
		return logo;
	}
	public void setLogo(String logo) {
		this.logo = logo;
	}
	public String getDescription() {
		return description;
	}
	public void setDescription(String description) {
		this.description = description;
	}
	public Boolean getDeleted() {
		return deleted;
	}
	public void setDeleted(Boolean deleted) {
		this.deleted = deleted;
	}
	public Date getGmtCreate() {
		return gmtCreate;
	}
	public void setGmtCreate(Date gmtCreate) {
		this.gmtCreate = gmtCreate;
	}
	public Date getGmtModified() {
		return gmtModified;
	}
	public void setGmtModified(Date gmtModified) {
		this.gmtModified = gmtModified;
	}
	public Integer getRemaining() {
		return remaining;
	}
	public void setRemaining(Integer remaining) {
		this.remaining = remaining;
	}
}

==> activity-center-api-3.1.32-sources.jar: cn/com/duiba/activity/center/api/dto/ngame/DuibaNgameOptionsDto.java <==
package cn.com.duiba.activity.center.api.dto.ngame;

import java.io.Serializable;
import java.util.Date;

/**
 * 
 * ClassName: DuibaNgameOptionsDto <br/>
 * date: 2016年12月1日 上午9:46:11 <br/>
 *
 * @version 
 * @since JDK 1.6
 */
public class DuibaNgameOptionsDto implements Serializable{
	/**
	 * extJson扩展json字段key定义：奖项发放限制类型:1，永久；2，每日；3，自定义周期
	 */
	public static final String EXT_JSON_KEY_LIMIT_TYPE = "limitTimeType";
	/**
	 * extendJson扩展json字段key定义：奖项发放限制自定义天数
	 */
	public static final String EXT_JSON_KEY_LIMIT_DAYS = "limitDays";

	/** 多游戏排行榜奖项发放名次集合 */
	public static final String EXT_JSON_KEY_MULTI_RANKING  = "ranking";

	private static final long serialVersionUID = -9137580180385890159L;
	private Long id;
	private Long duibaGameId;
	private Long itemId;
	private String prizeName;
	private Integer payload;
	private String prizeType;
	private String facePrice;
	private Boolean hidden;
	private Boolean autoOpen;
	private String logo;
	private String description;
	private Boolean deleted;
	private Date gmtCreate;
	private Date gmtModified;
	private Integer remaining;
	private Boolean isMutliPrizeLimit;
	
	/*奖项个数*/
	private Integer optionCount;
	/*新增奖项个数*/
	private Integer newOptionCount;
	private String itemName;
	
	private Boolean valid;
	private Boolean addrLimit;

	private Integer guarantee; //奖品保底值开关
	private String scoreArea; //奖项中奖区间
	private Integer optionLimitCount; //奖品中奖次数限制
	private Integer rate; //奖品中奖几率
	private String extJson;//扩展字段,暂有时间限制类型和限制天数

	public String getExtJson() {
		return extJson;
	}

	public void setExtJson(String extJson) {
		this.extJson = extJson;
	}

	public Integer getGuarantee() {
		return guarantee;
	}

	public void setGuarantee(Integer guarantee) {
		this.guarantee = guarantee;
	}

	public String getScoreArea() {
		return scoreArea;
	}

	public void setScoreArea(String scoreArea) {
		this.scoreArea = scoreArea;
	}

	public Integer getOptionLimitCount() {
		return optionLimitCount;
	}

	public void setOptionLimitCount(Integer optionLimitCount) {
		this.optionLimitCount = optionLimitCount;
	}

	public Integer getRate() {
		return rate;
	}

	public void setRate(Integer rate) {
		this.rate = rate;
	}

	public Long getDuibaGameId() {
		return duibaGameId;
	}
	public void setDuibaGameId(Long duibaGameId) {
		this.duibaGameId = duibaGameId;
	}
	public String getPrizeName() {
		return prizeName;
	}
	public void setPrizeName(String prizeName) {
		this.prizeName = prizeName;
	}
	public Boolean getAutoOpen() {
		return autoOpen;
	}
	public void setAutoOpen(Boolean autoOpen) {
		this.autoOpen = autoOpen;
	}
	public Boolean getValid() {
		return valid;
	}
	public void setValid(Boolean valid) {
		this.valid = valid;
	}
	public Boolean getAddrLimit() {
		return addrLimit;
	}
	public void setAddrLimit(Boolean addrLimit) {
		this.addrLimit = addrLimit;
	}
	public Integer getNewOptionCount() {
		return newOptionCount;
	}
	public void setNewOptionCount(Integer newOptionCount) {
		this.newOptionCount = newOptionCount;
	}
	public Integer getOptionCount() {
		return optionCount;
	}
	public void setOptionCount(Integer optionCount) {
		this.optionCount = optionCount;
	}
	public Long getId() {
		return id;
	}
	public void setId(Long id) {
		this.id = id;
	}
	public Long getItemId() {
		return itemId;
	}
	public void setItemId(Long itemId) {
		this.itemId = itemId;
	}
	public Integer getPayload() {
		return payload;
	}
	public void setPayload(Integer payload) {
		this.payload = payload;
	}
	public String getPrizeType() {
		return prizeType;
	}
	public void setPrizeType(String prizeType) {
		this.prizeType = prizeType;
	}
	public String getFacePrice() {
		return facePrice;
	}
	public void setFacePrice(String facePrice) {
		this.facePrice = facePrice;
	}
	public Boolean getHidden() {
		return hidden;
	}
	public void setHidden(Boolean hidden) {
		this.hidden = hidden;
	}
	public String getLogo() {
		return logo;
	}
	public void setLogo(String logo) {
		this.logo = logo;
	}
	public String getDescription() {
		return description;
	}
	public void setDescription(String description) {
		this.description = description;
	}
	public Boolean getDeleted() {
		return deleted;
	}
	public void setDeleted(Boolean deleted) {
		this.deleted = deleted;
	}
	public Date getGmtCreate() {
		return gmtCreate;
	}
	public void setGmtCreate(Date gmtCreate) {
		this.gmtCreate = gmtCreate;
	}
	public Date getGmtModified() {
		return gmtModified;
	}
	public void setGmtModified(Date gmtModified) {
		this.gmtModified = gmtModified;
	}
	public Integer getRemaining() {
		return remaining;
	}
	public void setRemaining(Integer remaining) {
		this.remaining = remaining;
	}
    
    public String getItemName() {
        return itemName;
    }
    
    public void setItemName(String itemName) {
        this.itemName = itemName;
    }


	public Boolean getMutliPrizeLimit() {
		return isMutliPrizeLimit;
	}

	public void setMutliPrizeLimit(Boolean mutliPrizeLimit) {
		isMutliPrizeLimit = mutliPrizeLimit;
	}
}
